@@ -5,5 +5,8 @@ p <- ggplot(mtcars) +
                  colour = factor(gear))) + facet_wrap( ~ am)
 
 test_that("Plotting works without warnings", {
-  expect_silent(p + theme_publish())
+  expect_silent(print(p))
+  
+  skip_if(packageVersion("ggplot2")>="3.3.6.9000")
+  expect_silent(print(p + theme_publish()))
 })
